{*      midasdll.pas
 *
 * MIDAS DLL programming interface
 * TMT Pascal Multi-target interface unit (visit our site http://www.tmt.com)
 * Target: Win32 (Windows'95, Windows'98, Windows NT)
 *
 * $Id: midasdll.pas,v 1.5 1997/07/31 14:30:58 pekangas Exp $
 *
 * Copyright 1996,1997 Housemarque Inc
 * Ported by Vadim Bodrov, TMT Development Corporation, 1998,1999
 *
 * This file is part of MIDAS Digital Audio System, and may only be
 * used, modified and distributed under the terms of the MIDAS
 * Digital Audio System license, "license.txt". By continuing to use,
 * modify or distribute this file you indicate that you have
 * read the license and understand and accept it fully.
*}

unit midasdll;


interface


uses Windows;


const
    { enum MIDASoptions }
    MIDAS_OPTION_NONE = 0;
    MIDAS_OPTION_MIXRATE = 1;
    MIDAS_OPTION_OUTPUTMODE = 2;
    MIDAS_OPTION_MIXBUFLEN = 3;
    MIDAS_OPTION_MIXBUFBLOCKS = 4;
    MIDAS_OPTION_DSOUND_MODE = 5;
    MIDAS_OPTION_DSOUND_HWND = 6;
    MIDAS_OPTION_DSOUND_OBJECT = 7;
    MIDAS_OPTION_DSOUND_BUFLEN = 8;
    MIDAS_OPTION_16BIT_ULAW_AUTOCONVERT = 9;
    MIDAS_OPTION_FILTER_MODE = 10;
    MIDAS_OPTION_MIXING_MODE = 11;
    MIDAS_OPTION_DEFAULT_STEREO_SEPARATION = 12;
    MIDAS_OPTION_FORCE_NO_SOUND = 13;



    { enum MIDASmodes }
    MIDAS_MODE_NONE = 0;
    MIDAS_MODE_MONO = 1;
    MIDAS_MODE_STEREO = 2;
    MIDAS_MODE_8BIT = 4;
    MIDAS_MODE_16BIT = 8;
    MIDAS_MODE_8BIT_MONO = MIDAS_MODE_8BIT or MIDAS_MODE_MONO;
    MIDAS_MODE_8BIT_STEREO = MIDAS_MODE_8BIT or MIDAS_MODE_STEREO;
    MIDAS_MODE_16BIT_MONO = MIDAS_MODE_16BIT or MIDAS_MODE_MONO;
    MIDAS_MODE_16BIT_STEREO = MIDAS_MODE_16BIT or MIDAS_MODE_STEREO;

    { enum MIDASsampleTypes }
    MIDAS_SAMPLE_NONE = 0;
    MIDAS_SAMPLE_8BIT_MONO = 1;
    MIDAS_SAMPLE_16BIT_MONO = 2;
    MIDAS_SAMPLE_8BIT_STEREO = 3;
    MIDAS_SAMPLE_16BIT_STEREO = 4;
    MIDAS_SAMPLE_ADPCM_MONO = 5;
    MIDAS_SAMPLE_ADPCM_STEREO = 6;
    MIDAS_SAMPLE_ULAW_MONO = 7;
    MIDAS_SAMPLE_ULAW_STEREO = 8;

    { enum MIDASloop }
    MIDAS_LOOP_NO = 0;
    MIDAS_LOOP_YES = 1;

    { enum MIDASpanning }
    MIDAS_PAN_LEFT = -64;
    MIDAS_PAN_MIDDLE = 0;
    MIDAS_PAN_RIGHT = 64;
    MIDAS_PAN_SURROUND = $80;

    { enum MIDASchannels }
    MIDAS_CHANNEL_AUTO = $FFFF;
    MIDAS_ILLEGAL_CHANNEL = $FFFF;

    { enum MIDASdsoundModes }
    MIDAS_DSOUND_DISABLED = 0;
    MIDAS_DSOUND_STREAM = 1;
    MIDAS_DSOUND_PRIMARY = 2;
    MIDAS_DSOUND_FORCE_STREAM = 3;

    { enum MIDASpositions }
    MIDAS_POSITION_DEFAULT = $FFFFFFFF;

    { enum MIDASfilterModes }
    MIDAS_FILTER_NONE = 0;
    MIDAS_FILTER_LESS = 1;
    MIDAS_FILTER_MORE = 2;
    MIDAS_FILTER_AUTO = 3;

    { enum MIDASechoFilterTypes }
    MIDAS_ECHO_FILTER_NONE = 0;
    MIDAS_ECHO_FILTER_LOWPASS = 1;
    MIDAS_ECHO_FILTER_HIGHPASS = 2;

    { enum MIDASmixingModes }
    MIDAS_MIX_NORMAL_QUALITY = 0;
    MIDAS_MIX_HIGH_QUALITY = 1;

    { enum MIDASsamplePlayStatus }
    MIDAS_SAMPLE_STOPPED = 0;
    MIDAS_SAMPLE_PLAYING = 1;



type MIDASmoduleInfo =
    record
        songName : array[0..31] of char;
        songLength : Longint;
        numPatterns : Longint;
        numInstruments : Longint;
        numChannels : Longint;
    end;
    PMIDASmoduleInfo = ^MIDASmoduleInfo;

type MIDASinstrumentInfo =
    record
        instName : array[0..31] of char;
    end;
    PMIDASinstrumentInfo = ^MIDASinstrumentInfo;

type MIDASplayStatus =
    record
        position : dword;
        pattern : dword;
        row : dword;
        syncInfo : Longint;
        songLoopCount : dword
    end;
    PMIDASplayStatus = ^MIDASplayStatus;

type MIDASecho =
    record
        delay : dword;
        gain : Longint;
        reverseChannels : Longint;
        filterType : dword;
    end;
    PMIDASecho = ^MIDASecho;

type MIDASechoSet =
    record
        feedback : Longint;
        gain : Longint;
        numEchoes : Longint;
        echoes : PMIDASecho;
    end;
    PMIDASechoSet = ^MIDASechoSet;


    MIDASmodule = pointer;
    MIDASmodulePlayHandle = DWORD;
    MIDASsample = DWORD;
    MIDASsamplePlayHandle = DWORD;
    MIDASstreamHandle = pointer;
    Pbyte = ^byte;
    MIDASechoHandle = pointer;

const
    DLLNAME = 'midas11.dll';

function MIDASgetLastError conv arg_stdcall: Longint;
     external DLLNAME name '_MIDASgetLastError@0';
function MIDASgetErrorMessage conv arg_stdcall (errorCode : Longint) : PChar;
     external DLLNAME name '_MIDASgetErrorMessage@4';

function MIDASstartup conv arg_stdcall : boolean;
     external DLLNAME name '_MIDASstartup@0';
function MIDASconfig conv arg_stdcall : boolean;
     external DLLNAME name '_MIDASconfig@0';
function MIDASloadConfig conv arg_stdcall (fileName : PChar) : boolean;
     external DLLNAME name '_MIDASloadConfig@4';
function MIDASsaveConfig conv arg_stdcall (fileName : PChar) : boolean;
     external DLLNAME name '_MIDASsaveConfig@4';
function MIDASreadConfigRegistry conv arg_stdcall (key : dword; subKey : PChar) : boolean;
     external DLLNAME name '_MIDASreadConfigRegistry@8';
function MIDASwriteConfigRegistry conv arg_stdcall (key : dword; subKey : PChar) : boolean;
     external DLLNAME name '_MIDASwriteConfigRegistry@8';


function MIDASinit conv arg_stdcall : boolean;
     external DLLNAME name '_MIDASinit@0';
function MIDASsetOption conv arg_stdcall (option : Longint; value : dword) : boolean;
     external DLLNAME name '_MIDASsetOption@8';
function MIDASgetOption conv arg_stdcall (option : Longint) : dword;
     external DLLNAME name '_MIDASgetOption@4';
function MIDASclose conv arg_stdcall : boolean;
     external DLLNAME name '_MIDASclose@0';
function MIDASsuspend conv arg_stdcall : boolean;
     external DLLNAME name '_MIDASsuspend@0';
function MIDASresume conv arg_stdcall : boolean;
     external DLLNAME name '_MIDASresume@0';
function MIDASopenChannels conv arg_stdcall (numChannels : Longint) : boolean;
     external DLLNAME name '_MIDASopenChannels@4';
function MIDAScloseChannels conv arg_stdcall : boolean;
     external DLLNAME name '_MIDAScloseChannels@0';
function MIDASsetAmplification conv arg_stdcall (amplification : dword) : boolean;
     external DLLNAME name '_MIDASsetAmplification@4';
function MIDASstartBackgroundPlay conv arg_stdcall (pollRate : dword) : boolean;
     external DLLNAME name '_MIDASstartBackgroundPlay@4';
function MIDASstopBackgroundPlay conv arg_stdcall : boolean;
     external DLLNAME name '_MIDASstopBackgroundPlay@0';
function MIDASpoll conv arg_stdcall : boolean;
     external DLLNAME name '_MIDASpoll@0';
function MIDASlock conv arg_stdcall : boolean;
     external DLLNAME name '_MIDASlock@0';
function MIDASunlock conv arg_stdcall : boolean;
     external DLLNAME name '_MIDASunlock@0';
function MIDASgetVersionString conv arg_stdcall : PChar;
     external DLLNAME name '_MIDASgetVersionString@0';

function MIDASallocateChannel conv arg_stdcall : dword;
     external DLLNAME name '_MIDASallocateChannel@0';
function MIDASfreeChannel conv arg_stdcall (channel : dword) : boolean;
     external DLLNAME name '_MIDASfreeChannel@4';

function MIDASloadModule conv arg_stdcall (fileName : PChar) : MIDASmodule;
     external DLLNAME name '_MIDASloadModule@4';
function MIDASplayModule conv arg_stdcall (module : MIDASmodule; loopSong : LongBool) :
    MIDASmodulePlayHandle;
     external DLLNAME name '_MIDASplayModule@8';
function MIDASplayModuleSection conv arg_stdcall (module : MIDASmodule; startPos, endPos,
    restartPos : dword; loopSong : LongBool) : MIDASmodulePlayHandle;
     external DLLNAME name '_MIDASplayModuleSection@20';
function MIDASstopModule conv arg_stdcall (playHandle : MIDASmodulePlayHandle) : boolean ;
     external DLLNAME name '_MIDASstopModule@4';
function MIDASfreeModule conv arg_stdcall (module : MIDASmodule) : boolean;
     external DLLNAME name '_MIDASfreeModule@4';

function MIDASgetPlayStatus conv arg_stdcall (playHandle : MIDASmodulePlayHandle;
    status : PMIDASplayStatus) : boolean;
     external DLLNAME name '_MIDASgetPlayStatus@8';
function MIDASsetPosition conv arg_stdcall (playHandle : MIDASmodulePlayHandle;
    newPosition : Longint) : boolean;
     external DLLNAME name '_MIDASsetPosition@8';
function MIDASsetMusicVolume conv arg_stdcall (playHandle : MIDASmodulePlayHandle;
    volume : dword) : boolean;
     external DLLNAME name '_MIDASsetMusicVolume@8';
function MIDASgetModuleInfo conv arg_stdcall (module : MIDASmodule; info : PMIDASmoduleInfo) :
    boolean;
     external DLLNAME name '_MIDASgetModuleInfo@8';
function MIDASgetInstrumentInfo conv arg_stdcall (module : MIDASmodule; instNum : Longint;
    info : PMIDASinstrumentInfo) : boolean;
     external DLLNAME name '_MIDASgetInstrumentInfo@12';
function MIDASfadeMusicChannel conv arg_stdcall (playHandle : MIDASmodulePlayHandle; channel,
    fade : dword) : boolean;
     external DLLNAME name '_MIDASfadeMusicChannel@12';

function MIDASloadRawSample conv arg_stdcall (fileName : PChar; sampleType,
    loopSample : Longint) : MIDASsample;
     external DLLNAME name '_MIDASloadRawSample@12';
function MIDASloadWaveSample conv arg_stdcall (fileName : PChar; loopSample : Longint) :
    MIDASsample;
     external DLLNAME name '_MIDASloadWaveSample@8';
function MIDASfreeSample conv arg_stdcall (sample : MIDASsample) : boolean;
     external DLLNAME name '_MIDASfreeSample@4';
function MIDASallocAutoEffectChannels conv arg_stdcall (numChannels : dword) : boolean;
     external DLLNAME name '_MIDASallocAutoEffectChannels@4';
function MIDASfreeAutoEffectChannels conv arg_stdcall : boolean;
     external DLLNAME name '_MIDASfreeAutoEffectChannels@0';
function MIDASplaySample conv arg_stdcall (sample : midasSample; channel : dword;
    priority : Longint; rate, volume : dword; panning : Longint) :
    MIDASsamplePlayHandle;
     external DLLNAME name '_MIDASplaySample@24';
function MIDASstopSample conv arg_stdcall (sample : MIDASsamplePlayHandle) : boolean;
     external DLLNAME name '_MIDASstopSample@4';
function MIDASsetSampleRate conv arg_stdcall (sample : MIDASsamplePlayHandle; rate : dword) :
    boolean;
     external DLLNAME name '_MIDASsetSampleRate@8';
function MIDASsetSampleVolume conv arg_stdcall (sample : MIDASsamplePlayHandle; volume : dword)
    : boolean;
     external DLLNAME name '_MIDASsetSampleVolume@8';
function MIDASsetSamplePanning conv arg_stdcall (sample : MIDASsamplePlayHandle;
    panning : Longint) : boolean;
     external DLLNAME name '_MIDASsetSamplePanning@8';
function MIDASsetSamplePriority conv arg_stdcall (sample : MIDASsamplePlayHandle;
    priority : Longint) : boolean;
     external DLLNAME name '_MIDASsetSamplePriority@8';
function MIDASgetSamplePlayStatus conv arg_stdcall (sample : MIDASsamplePlayHandle) : dword;
     external DLLNAME name '_MIDASgetSamplePlayStatus@4';

function MIDASplayStreamFile conv arg_stdcall (fileName : PChar;
    sampleType : dword; sampleRate : dword; bufferLength : dword;
    loopStream : Longint) : MIDASstreamHandle;
     external DLLNAME name '_MIDASplayStreamFile@20';
function MIDASplayStreamWaveFile conv arg_stdcall (fileName : PChar; bufferLength : dword;
    loopStream : Longint) : MIDASstreamHandle;
     external DLLNAME name '_MIDASplayStreamWaveFile@12';
function MIDASstopStream conv arg_stdcall (stream : MIDASstreamHandle) : boolean;
     external DLLNAME name '_MIDASstopStream@4';

function MIDASplayStreamPolling conv arg_stdcall (sampleType : dword;
    sampleRate : dword; bufferLength : dword) : MIDASstreamHandle;
     external DLLNAME name '_MIDASplayStreamPolling@12';
function MIDASfeedStreamData conv arg_stdcall (stream : MIDASstreamHandle; data : Pbyte;
    numBytes : dword; feedAll : LongBool) : dword;
     external DLLNAME name '_MIDASfeedStreamData@16';

function MIDASsetStreamRate conv arg_stdcall (stream : MIDASstreamHandle; rate : dword)
    : boolean;
     external DLLNAME name '_MIDASsetStreamRate@8';
function MIDASsetStreamVolume conv arg_stdcall (stream : MIDASstreamHandle; volume : dword)
    : boolean;
     external DLLNAME name '_MIDASsetStreamVolume@8';
function MIDASsetStreamPanning conv arg_stdcall (stream : MIDASstreamHandle; panning : Longint)
     : boolean;
      external DLLNAME name '_MIDASsetStreamPanning@8';

function MIDASgetStreamBytesBuffered conv arg_stdcall (stream : MIDASstreamHandle) : boolean;
     external DLLNAME name '_MIDASgetStreamBytesBuffered@4';
function MIDASpauseStream conv arg_stdcall (stream : MIDASstreamHandle) : boolean;
     external DLLNAME name '_MIDASpauseStream@4';
function MIDASresumeStream conv arg_stdcall (stream : MIDASstreamHandle ) : boolean;
     external DLLNAME name '_MIDASresumeStream@4';

function MIDASaddEchoEffect conv arg_stdcall (echoSet : PMIDASechoSet) : MIDASechoHandle;
     external DLLNAME name '_MIDASaddEchoEffect@4';
function MIDASremoveEchoEffect conv arg_stdcall (echoHandle : MIDASechoHandle) : boolean;
     external DLLNAME name '_MIDASremoveEchoEffect@4';

implementation

(* Noting to implement *)

END.

{*
 * $Log: DLLNAME.pas,v $
 * Revision 1.5  1997/07/31 14:30:58  pekangas
 * Added option MIDAS_OPTION_FORCE_NO_SOUND
 *
 * Revision 1.4  1997/07/31 10:56:48  pekangas
 * Renamed from MIDAS Sound System to MIDAS Digital Audio System
 *
 * Revision 1.3  1997/07/29 16:57:12  pekangas
 * Added sample playing status query
 *
 * Revision 1.2  1997/07/29 16:51:09  pekangas
 * Updated for 1.1 beta 1
 *
 * Revision 1.1  1997/05/23 14:47:44  pekangas
 * Initial revision
 *
*}