/////////////////////////////////////////////////////////////////////
//                                                                 //
// Midas Audio System Player Demo                                  //
// Fully written on TMT Pascal Multi-target (http://www.tmt.com)   //
// Target: Win32 (Windows'95, Windows'98, Windows NT)              //
//                                                                 //
/////////////////////////////////////////////////////////////////////

program MPlay;

uses Windows, Messages, CommDlg, CommCtrl, Strings, MIDASDLL;

{$r mplay.res}

const
  LOAD_BUTTON      = 1000;
  PLAY_BUTTON      = 1001;
  SLIDER           = 1002;
  ABOUT_BUTTON     = 1003;
  STOP_BUTTON      = 1004;

  TIMER_ID         = 1;

  ALL_MODULES      = '*.mod;*.s3m;*.xm;*.mdz;*.s3z;*.xmz';
  UNPACKED_MODULES = '*.mod;*.s3m;*.xm';
  PACKED_MODULES   = '*.mdz;*.s3z;*.xmz;*.zip';

  FILTER           = 'All Modules ('+ALL_MODULES+')'+#0+ALL_MODULES+#0+
                     'Unpacked Modules ('+UNPACKED_MODULES+')'+#0+UNPACKED_MODULES+#0+
                     'Packed Modules ('+PACKED_MODULES+')'+#0+PACKED_MODULES+#0+
                     'All Files (*.*)'+#0+'*.*'+#0+
                     #0+#0;

var
  mainDlg          : THandle;
  Msg              : TMsg;
  module           : MIDASmodule := nil;
  playHandle       : MIDASmodulePlayHandle := 0;

function OpenFile: String;
var
  OFN: TOpenFileName;
  FileName: array [0..MAX_PATH] of char;
begin
  FillChar(OFN, SizeOf(OFN), 0);
  OFN.lStructSize := SizeOf(OFN);
  FileName := ''+#0;
  OFN.lpstrFilter := Filter;
  OFN.lpstrFile := FileName;
  OFN.HInstance := HInstance;
  OFN.nMaxFile  := MAX_PATH;
  if GetOpenFileName(OFN) then
    Result := StrPas(FileName)
  else
    Result  := '';
end;

procedure MIDASerror;
begin
  if MIDASgetLastError <> 0 then
  begin
    MessageBox(HInstance, MIDASgetErrorMessage(MIDASgetLastError),
      'MIDAS Error', MB_OK or MB_ICONERROR);
    if not (MIDASgetLastError in [15,22,23,29]) then
    begin
      MIDASclose;
      halt;
    end;
  end;
end;

function LoadModule(Name: String): Boolean;
var
  s: array[0..512] of Char;
  i: MIDASmoduleInfo;
  FileName: String;
begin
  if Name = '' then
    FileName := OpenFile
  else
    FileName := Name;
  if FileName <> '' then
  begin
    if playHandle <> 0 then
      if not MIDASstopModule(playHandle) then MIDASerror;
    playHandle := 0;
    if module <> NIL then
      if not MIDASfreeModule(module) then MIDASerror;
    module := NIL;
    module := MIDASloadModule(StrPCopy(@s, FileName));
    if module = NIL then MIDASerror;
    if not MIDASgetModuleInfo(module, @i) then MIDASerror;
    if i.songname <> '' then
      SetWindowText(mainDlg, i.songname)
    else
      SetWindowText(mainDlg, 'Midas Player');
    SendDlgItemMessage(mainDlg, SLIDER, TBM_SETRANGEMAX, LONGTRUE, i.songLength - 1);
    Result := TRUE;
 end else
    Result := FALSE;
end;

procedure PlayModule;
begin
  if module = NIL then exit;
  if playHandle <> 0 then
    if not MIDASstopModule(playHandle) then MIDASerror;
  playHandle := MIDASplayModule(module, LongTrue);
  if playHandle = 0 then MIDASerror;
end;

procedure StopModule;
begin
  if playHandle <> 0 then
    if not MIDASstopModule(playHandle) then
      MIDASerror
    else
      playHandle := 0;
end;

procedure TimerProc conv arg_stdcall (hwnd: HWND;  uMsg, idEvent: UInt; dwTime: DWord);
var
  s : MIDASplayStatus;
begin
{$optreg-}
  if playHandle = 0 then
  begin
    SendDlgItemMessage(mainDlg, SLIDER, TBM_SETPOS, LONGTRUE, 0);
  end
  else begin
    if not MIDASgetPlayStatus(playHandle, @s) then MIDASerror;
    SendDlgItemMessage(mainDlg, SLIDER, TBM_SETPOS, LONGTRUE, s.position);
  end;
{$optreg-}
end;

function AboutDlgProc conv arg_stdcall (Dialog: HWND; Mess: UINT; WParam: WParam;
 LParam: LParam): LongInt;
const
  OK_BUTTON = 1;
begin
{$optreg-}
  if (Mess = WM_CLOSE) or ((Mess = WM_COMMAND) and
     (LoWord(WParam) = OK_BUTTON)) then
  begin
    EndDialog(Dialog, 0);
    Result := 1;
  end else
    Result := 0;
{$optreg+}
end;

function MainDlgProc conv arg_stdcall (Dialog: HWND; Mess: UINT; WParam: WParam;
 LParam: LParam): LongInt;
 var ScrollPos: DWord;
begin
{$optreg-}
 case Mess of
  WM_INITDIALOG: begin
                   SetFocus(GetDlgItem(Dialog, LOAD_BUTTON));
                   Result := 0;
                 end;
  WM_HSCROLL:    begin
                   if playHandle = 0 then
                     Result := 0
                   else begin
                     ScrollPos := SendDlgItemMessage(mainDlg, SLIDER, TBM_GETPOS, 0, 0);
                     MIDASsetPosition(playHandle, ScrollPos);
                     Result := 1;
                   end;
                 end;
  WM_CLOSE:      begin
                   Result := 0;
                   DestroyWindow(Dialog);
                 end;
  WM_COMMAND:    begin
                   if LoWord(WParam) = ABOUT_BUTTON then begin
                     DialogBoxParam(HInstance, MAKEINTRESOURCE(102), maindlg, @AboutDlgProc, 0);
                   end;
                   if LoWord(WParam) = LOAD_BUTTON then begin
                     if LoadModule('') then
                       PlayModule;
                   end;
                   if LoWord(WParam) = PLAY_BUTTON then begin
                     PlayModule;
                   end;
                   if LoWord(WParam) = STOP_BUTTON then begin
                     StopModule;
                   end;
                   Result := 1;
                 end;
  WM_DESTROY:    begin
                   PostQuitMessage(0);
                   Result := 0;
                 end;
 else
                 Result := 0;
 end;
{$optreg+}
end;

begin
  InitCommonControls;
  MIDASstartup;
  mainDlg := CreateDialog(HInstance, MakeIntResource(101), 0, @MainDlgProc);
  if ParamCount > 0 then
  begin
    if (AnsiLowerCase(ParamStr(1)) = '-config') or
      (AnsiLowerCase(ParamStr(1)) = '-c') then
    begin
      if not MIDASconfig then
        MIDASerror;
      if not MIDASinit then MIDASerror;
      if not MIDASstartBackgroundPlay(0) then
        MIDASerror;
    end else
    begin
      if not MIDASinit then MIDASerror;
      if not MIDASstartBackgroundPlay(0) then
        MIDASerror;
      LoadModule(ParamStr(1));
      PlayModule;
    end;
  end else
  begin
    if not MIDASinit then MIDASerror;
    if not MIDASstartBackgroundPlay(0) then
      MIDASerror;
  end;

  ShowWindow(mainDlg, SW_SHOW);

  SendMessage(mainDlg, WM_SETICON, ICON_SMALL, LoadIcon(hInstance, MAKEINTRESOURCE(102)));
  SendMessage(mainDlg, WM_SETICON, ICON_BIG, LoadIcon(hInstance, MAKEINTRESOURCE(102)));

  SetTimer(mainDlg, TIMER_ID, 1000, @TimerProc);

  while GetMessage(Msg,0,0,0) do begin
    TranslateMessage(Msg);
    DispatchMessage(Msg);
  end;
  KillTimer(mainDlg, TIMER_ID);

  if not MIDASstopBackgroundPlay then MIDASerror;
  MIDASclose;
end.

